==> haskell-postgresql-binary-0.12.5-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-binary
version:              0.12.5
visibility:           public
id:                   postgresql-binary-0.12.5-DrbnYr9xjAE8H2D7nQzPOk
key:                  postgresql-binary-0.12.5-DrbnYr9xjAE8H2D7nQzPOk
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/postgresql-binary 
synopsis:             Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.

    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql hasql>
    is based on this library.

    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.

category:             PostgreSQL, Database, Codecs, Parsing
abi:                  78b259b5440bb5cc875d303022f88e65
exposed:              True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding

hidden-modules:
    PostgreSQL.Binary.Encoding.Builders PostgreSQL.Binary.Prelude
    PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
    PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
    PostgreSQL.Binary.Inet PostgreSQL.Binary.BuilderPrim

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-binary
hs-libraries:         HSpostgresql-binary-0.12.5-DrbnYr9xjAE8H2D7nQzPOk
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv base-4.17.2.1
    binary-parser-0.5.7.6-KAz87kuVTjWJFIHzQkScCm bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.7-Hc9VY3hyuQyFpFp37BbFT4
    containers-0.6.7 network-ip-0.3.0.3-5WdjQywsMbF4EzdCNS1czL
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    uuid-1.3.16-DTXFgrb7MThGeAanhZvVIB
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.5-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-binary
version:              0.12.5
visibility:           public
id:                   postgresql-binary-0.12.5-2aYZhE6puLH4xUhH2CxOYP
key:                  postgresql-binary-0.12.5-2aYZhE6puLH4xUhH2CxOYP
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/postgresql-binary 
synopsis:             Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.

    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql hasql>
    is based on this library.

    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.

category:             PostgreSQL, Database, Codecs, Parsing
abi:                  4cb50e732fe10cc9322a167646ec22b4
exposed:              True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding

hidden-modules:
    PostgreSQL.Binary.Encoding.Builders PostgreSQL.Binary.Prelude
    PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
    PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
    PostgreSQL.Binary.Inet PostgreSQL.Binary.BuilderPrim

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-binary
hs-libraries:         HSpostgresql-binary-0.12.5-2aYZhE6puLH4xUhH2CxOYP
depends:
    aeson-2.1.2.1-Gng3eoGBP2Sj2fbUBsnWH base-4.17.2.1
    binary-parser-0.5.7.7-9HXTUOLuqkm8u3pHBYMZFa bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.7-H1nff9M0pPA5q1O1q5eXjW
    containers-0.6.7 network-ip-0.3.0.3-7YK5W4dSezI7VgiXCycVI3
    scientific-0.3.7.0-43723I2k3fJ8FjtljY7WIm text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W
    uuid-1.3.16-Dwhy0JVF1AV9mSE706nnCp
    vector-0.13.2.0-G0g5gCprguQ6M58H7uQE53

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
